@@ -5,7 +5,7 @@ This also includes overall duel stats.
 from .errors import StatError
 from .minecraftstats import get_user_stats
 
-overall_functions = [
+overall_duel_functions = [
     "get_recent_games",
     "get_games_played",
     "get_current_winstreak",
@@ -127,7 +127,7 @@ __all__ = [
     "SumoDuelStats",
     "BridgeDuelStats",
     "SkyWarsDuelStats",
-    "overall_functions",
+    "overall_duel_functions",
     "classic_duel_functions",
     "op_duel_functions",
     "uhc_duel_functions",
@@ -369,4 +369,4 @@ class SkyWarsDuelStats(DuelStats):
     """Stats for SkyWars duels. All stats in here are just related to SkyWars duels."""
     def __init__(self):
         self.allowed_functions = skywars_duel_functions
-        super().__init__(mode="sw_duel", allowed_functions=self.allowed_functions)
+        super().__init__(mode="sw_duel", allowed_functions=self.allowed_functions)
\ No newline at end of file
