@@ -3,6 +3,7 @@
 Functions include getting duel and bedwars stats.
 """
 import requests
+from typing import Any, Dict
 
 from .errors import DataError
 
@@ -14,7 +15,7 @@ __all__ = [
 username = ""
 api_key = ""
 
-def set_username(user_name):
+def set_username(user_name) -> None:
     """Set the username to get the stats from."""
     global username
 
@@ -23,7 +24,7 @@ def set_username(user_name):
     else:
         raise TypeError(f"Input must be type str, not type {type(user_name).__name__}.")
 
-def set_api_key(apikey):
+def set_api_key(apikey) -> None:
     """Set the api key which is given to the user by Hypixel."""
     global api_key
 
@@ -32,7 +33,7 @@ def set_api_key(apikey):
     else:
         raise TypeError(f"Input must be type str, not type {type(apikey).__name__}.")
 
-def get_user_stats():
+def get_user_stats() -> Dict[str, Any]:
     """Get the user stats with the set username and api key."""
     if username != "" and api_key != "":
         data = requests.get(f"https://api.hypixel.net/player?key={api_key}&name={username}").json()
@@ -42,4 +43,4 @@ def get_user_stats():
             return data["player"]["stats"]
 
     else:
-        raise DataError("Username and/or API key must not be none.")    
+        raise DataError("Username and/or API key must not be none.")    
\ No newline at end of file
